"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const logger_1 = require("../common/logger");
class Settings {
    constructor(storage) {
        this.log = logger_1.LoggerFactory.getLogger('settings');
        this.upkEnabled = false;
        this.storage = storage;
    }
    reset() {
        this.log.trace('reset');
        this.deviceId = null;
        this.namespace = null;
        this.fidoPasskeyRegistered = false;
        this.fingerPrintTimestamp = null;
    }
    get deviceId() {
        return this.storage.getItem(this.getKey(Settings.DEVICE_ID_KEY));
    }
    set deviceId(val) {
        this.setOrRemove(Settings.DEVICE_ID_KEY, val);
    }
    get fidoPasskeyRegistered() {
        return this.storage.getItem(this.getKey(Settings.FIDO_PASSKEY_REGISTERED_KEY)) === 'true';
    }
    set fingerPrintTimestamp(val) {
        const assignedValue = val !== null ? val.toString() : null;
        this.setOrRemove(Settings.FP_TIMESTAMPT, assignedValue);
    }
    get fingerPrintTimestamp() {
        const storedTimestampString = this.storage.getItem(this.getKey(Settings.FP_TIMESTAMPT));
        if (!storedTimestampString) {
            return null;
        }
        let fingerprintTimestamp = parseInt(storedTimestampString);
        return isNaN(fingerprintTimestamp) ? null : fingerprintTimestamp;
    }
    set fidoPasskeyRegistered(val) {
        this.setOrRemove(Settings.FIDO_PASSKEY_REGISTERED_KEY, val ? 'true' : null);
    }
    get namespace() {
        return this.storage.getItem(this.getKey(Settings.NAMESPACE_KEY));
    }
    set namespace(val) {
        this.log.trace('namespace set to ' + val);
        this.setOrRemove(Settings.NAMESPACE_KEY, val);
    }
    getKey(key) {
        return `${Settings.KEY_PREFIX}.${key}`;
    }
    setOrRemove(key, val) {
        if (val) {
            this.storage.setItem(this.getKey(key), val);
        }
        else {
            this.storage.removeItem(this.getKey(key));
        }
    }
}
Settings.KEY_PREFIX = 'ProveAuth';
Settings.DEVICE_ID_KEY = 'DeviceId';
Settings.NAMESPACE_KEY = 'namespace';
Settings.FIDO_PASSKEY_REGISTERED_KEY = 'fidoPasskeyRegistered';
Settings.FP_TIMESTAMPT = 'fingerPrintTimestamp';
exports.default = Settings;
